==> lootr-fabric-1.21-1.10.35.93-sources.jar: noobanidus/mods/lootr/common/mixins/MixinLootTable.java <==
package noobanidus.mods.lootr.common.mixins;

import com.llamalad7.mixinextras.sugar.Local;
import it.unimi.dsi.fastutil.objects.ObjectArrayList;
import net.minecraft.util.RandomSource;
import net.minecraft.world.Container;
import net.minecraft.world.item.ItemStack;
import net.minecraft.world.level.storage.loot.LootContext;
import net.minecraft.world.level.storage.loot.LootParams;
import net.minecraft.world.level.storage.loot.LootTable;
import noobanidus.mods.lootr.common.api.LootrAPI;
import noobanidus.mods.lootr.common.api.data.DefaultLootFiller;
import noobanidus.mods.lootr.common.api.filter.ILootrFilter;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;

import java.util.List;

@Mixin(LootTable.class)
public class MixinLootTable {
  @Inject(method = "fill", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/level/storage/loot/LootTable;shuffleAndSplitItems(Lit/unimi/dsi/fastutil/objects/ObjectArrayList;ILnet/minecraft/util/RandomSource;)V"))
  private void LootrFill(Container container, LootParams lootParams, long l, CallbackInfo ci, @Local LootContext lootContext, @Local ObjectArrayList<ItemStack> items, @Local RandomSource random) {
    for (ILootrFilter filter : LootrAPI.getFilters()) {
      if (filter.mutate(items, DefaultLootFiller.getFillerState(), lootContext, random)) {
        break;
      }
    }
  }
}

==> lootr-fabric-1.21.4-1.13.36.89-sources.jar: noobanidus/mods/lootr/common/mixins/MixinLootTable.java <==
package noobanidus.mods.lootr.common.mixins;

import it.unimi.dsi.fastutil.objects.ObjectArrayList;
import net.minecraft.core.registries.Registries;
import net.minecraft.resources.ResourceKey;
import net.minecraft.server.MinecraftServer;
import net.minecraft.server.level.ServerLevel;
import net.minecraft.util.RandomSource;
import net.minecraft.world.Container;
import net.minecraft.world.item.ItemStack;
import net.minecraft.world.level.storage.loot.LootContext;
import net.minecraft.world.level.storage.loot.LootParams;
import net.minecraft.world.level.storage.loot.LootTable;
import noobanidus.mods.lootr.common.api.LootrAPI;
import noobanidus.mods.lootr.common.api.data.DefaultLootFiller;
import noobanidus.mods.lootr.common.api.filter.ILootrFilter;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;

import java.util.List;

@Mixin(LootTable.class)
public class MixinLootTable {
  @Inject(method = "fill", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/level/storage/loot/LootTable;shuffleAndSplitItems(Lit/unimi/dsi/fastutil/objects/ObjectArrayList;ILnet/minecraft/util/RandomSource;)V"), locals = LocalCapture.CAPTURE_FAILHARD)
  private void LootrFill(Container container, LootParams lootParams, long l, CallbackInfo ci, LootContext lootContext, ObjectArrayList<ItemStack> items, RandomSource random, List<Integer> slotList) {
    for (ILootrFilter filter : LootrAPI.getFilters()) {
      if (filter.mutate(items, DefaultLootFiller.getFillerState(), lootContext, random)) {
        break;
      }
    }
  }
}
